@@ -22,10 +22,10 @@ function(x, ..., row.index=c(1:10),
 
   print(x$run.jags)
   
-  T.index <- grep("T\\[",varnames(x$mcmc.list))    # markers
+  T.index <- grep("T\\[",coda::varnames(x$mcmc.list))    # markers
   T.print <- T.index[marker.index]                 # marker selection
   drop <- T.index
-  b.index <- grep("b\\[",varnames(x$mcmc.list)) # random effects if set
+  b.index <- grep("b\\[",coda::varnames(x$mcmc.list)) # random effects if set
   if (length(b.index>0)){
     b.print <- T.index[marker.index]
     drop <- c(T.index, b.index)
